.. haven documentation master file, created by
   sphinx-quickstart on Tue May 24 21:50:28 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to haven's documentation!
======================================

.. warning::

   This package is intended for use primarily by beamline staff. For
   user operations at the beamline, consider the *firefly* package.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   tutorials/index.rst
   topic_guides/index.rst
   haven/haven.rst



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
